package com.docus.server.api.recovery;

import com.docus.infrastructure.web.request.SearchDTO;
import com.docus.infrastructure.web.response.PageResult;
import com.docus.server.dto.recovery.rcvbasic.AddRcvBasicDTO;
import com.docus.server.dto.recovery.rcvbasic.DeleteRcvBasicDTO;
import com.docus.server.dto.recovery.rcvbasic.EditRcvBasicDTO;
import com.docus.server.vo.recovery.rcvbasic.RcvBasicVO;
import com.docus.server.vo.recovery.rcvbasic.SearchRcvBasicVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;


/**
 * 患者信息表 API
 *
 * @author AutoGenerator
 * @since 2023-09-13
 */
@FeignClient(value = "docus-recovery", contextId = "docus-recovery.RcvBasicApi")
@RequestMapping("/rcv/basic")
public interface RcvBasicApi {

    /**
     * 按主键查询
     *
     * @param id 主键id
     * @return 实体
     */
    @GetMapping("/find/{id}")
    RcvBasicVO findById(@PathVariable(value = "id") Serializable id);

    /**
     * 按主键集合查询
     *
     * @param ids 主键集合ids
     * @return 实体
     */
    @PostMapping("/findByIds")
    List<RcvBasicVO> findByIds(@RequestBody List<Serializable> ids);

    /**
     * 按属性查询多实体
     *
     * @param propertyName  属性名
     * @param propertyValue 属性值
     * @return 实体列表
     */
    @GetMapping("/findByProp")
    List<RcvBasicVO> findBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Object propertyValue);

    /**
     * 按属性值集合查询
     *
     * @param propertyName  属性名
     * @param propertyValue 属性值
     * @return 实体列表
     */
    @GetMapping("/findByProps")
    List<RcvBasicVO> findBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Collection<Serializable> propertyValue);

    /**
     * 按属性查询单实体
     *
     * @param propertyName  属性名
     * @param propertyValue 属性值
     * @return 实体
     */
    @GetMapping("/findOneByProp")
    RcvBasicVO findOneBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Object propertyValue);

    /**
     * 按属性值集合查询
     *
     * @param propertyName  属性名
     * @param propertyValue 属性值
     * @return 实体
     */
    @GetMapping("/findOneByProps")
    RcvBasicVO findOneBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Collection<Serializable> propertyValue);

    /**
     * 查询所有
     *
     * @return 实体
     */
    @GetMapping("/findAll")
    List<RcvBasicVO> findAll();

    /**
     * 关键字搜索(安卓)
     *
     * @param searchDTO 搜索参数
     * @return 分页列表
     */
    @PostMapping("/search")
    PageResult<SearchRcvBasicVO> search(@RequestBody SearchDTO searchDTO);

    /**
     * 关键字搜索(PC)
     *
     * @param searchDTO 搜索参数
     * @return 分页列表
     */
    @PostMapping("/page")
    PageResult<RcvBasicVO> page(@RequestBody SearchDTO searchDTO);

    /**
     * 新增
     *
     * @param addRcvBasicDTO 新增参数
     */
    @PostMapping("/add")
    void add(@RequestBody AddRcvBasicDTO addRcvBasicDTO);

    /**
     * 批量新增
     *
     * @param addRcvBasicDTOList 新增参数
     */
    @PostMapping("/addBatch")
    void addBatch(@RequestBody List<AddRcvBasicDTO> addRcvBasicDTOList);

    /**
     * 新增或编辑
     *
     * @param editRcvBasicDTO 新增或编辑参数
     */
    @PostMapping("/addOrEdit")
    void addOrEdit(@RequestBody EditRcvBasicDTO editRcvBasicDTO);

    /**
     * 批量新增或编辑
     *
     * @param editRcvBasicDTOList 新增或编辑参数
     */
    @PostMapping("/addOrEditBatch")
    void addOrEditBatch(@RequestBody List<EditRcvBasicDTO> editRcvBasicDTOList);

    /**
     * 编辑
     *
     * @param editRcvBasicDTO 编辑参数
     */
    @PutMapping("/edit")
    void edit(@RequestBody EditRcvBasicDTO editRcvBasicDTO);

    /**
     * 批量编辑
     *
     * @param serialNumbers 编辑参数
     */
    @PutMapping("/editBatchById")
    void editBatchById(@RequestBody List<Serializable> serialNumbers);

    /**
     * 批量删除
     *
     * @param deleteRcvBasicDTO 删除参数
     */
    @DeleteMapping("/delete")
    void delete(@RequestBody DeleteRcvBasicDTO deleteRcvBasicDTO);

    /**
     * 按主键删除
     *
     * @param id 删除参数
     */
    @DeleteMapping("/deleteById/{id}")
    void deleteById(@PathVariable(value = "id") Serializable id);

    /**
     * 按属性删除
     *
     * @param propertyName  删除属性名
     * @param propertyValue 删除属性值
     */
    @DeleteMapping("/deleteByProp")
    void deleteBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Object propertyValue);

    /**
     * 按属性值集合删除
     *
     * @param propertyName  删除属性名
     * @param propertyValue 删除属性值集合
     */
    @DeleteMapping("/deleteByProps")
    void deleteBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Collection<Serializable> propertyValue);

    /**
     * 按主键集合批量删除
     *
     * @param ids 删除参数
     */
    @DeleteMapping("/deleteByIds")
    void deleteByIds(@RequestBody Collection<Serializable> ids);

    /**
     * 名称不重复
     *
     * @param id   主键
     * @param name 名称
     * @return 名称重复数量
     */
    @GetMapping("/findByIdAndName")
    int findByIdAndName(@RequestParam("id") Serializable id, @RequestParam("name") String name);
}
