package com.docus.server.api.recovery;

import com.docus.infrastructure.web.request.SearchDTO;
import com.docus.infrastructure.web.response.PageResult;
import com.docus.server.dto.recovery.rcvsysuser.AddRcvSysUserDTO;
import com.docus.server.dto.recovery.rcvsysuser.DeleteRcvSysUserDTO;
import com.docus.server.dto.recovery.rcvsysuser.EditRcvSysUserDTO;
import com.docus.server.dto.recovery.rcvsysuser.LoginRcvSysUserDTO;
import com.docus.server.vo.recovery.rcvsysuser.RcvSysUserVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;


/**
 * 系统登录用户表 API
 *
 * @author AutoGenerator
 * @since 2023-09-13
 */
@FeignClient(value = "docus-recovery", contextId = "docus-recovery.RcvSysUserApi")
@RequestMapping("/rcv/sysUser")
public interface RcvSysUserApi {
    /**
     * 登录
     *
     * @return
     */
    @PostMapping("/login")
    String login(@RequestBody LoginRcvSysUserDTO loginRcvSysUserDTO);

    /**
     * 退出登录
     * @return
     */
    @GetMapping("/logout")
    boolean logout();

    /**
     * 按主键查询
     *
     * @param id 主键id
     * @return 实体
     */
    @GetMapping("/find/{id}")
    RcvSysUserVO findById(@PathVariable(value = "id") Serializable id);

    /**
     * 按主键集合查询
     *
     * @param ids 主键集合ids
     * @return 实体
     */
    @PostMapping("/findByIds")
    List<RcvSysUserVO> findByIds(@RequestBody List<Serializable> ids);

    /**
     * 按属性查询多实体
     *
     * @param propertyName  属性名
     * @param propertyValue 属性值
     * @return 实体列表
     */
    @GetMapping("/findByProp")
    List<RcvSysUserVO> findBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Object propertyValue);

    /**
     * 按属性值集合查询
     *
     * @param propertyName  属性名
     * @param propertyValue 属性值
     * @return 实体列表
     */
    @GetMapping("/findByProps")
    List<RcvSysUserVO> findBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Collection<Serializable> propertyValue);

    /**
     * 按属性查询单实体
     *
     * @param propertyName  属性名
     * @param propertyValue 属性值
     * @return 实体
     */
    @GetMapping("/findOneByProp")
    RcvSysUserVO findOneBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Object propertyValue);

    /**
     * 按属性值集合查询
     *
     * @param propertyName  属性名
     * @param propertyValue 属性值
     * @return 实体
     */
    @GetMapping("/findOneByProps")
    RcvSysUserVO findOneBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Collection<Serializable> propertyValue);

    /**
     * 查询所有
     *
     * @return 实体
     */
    @GetMapping("/findAll")
    List<RcvSysUserVO> findAll();

    /**
     * 关键字搜索
     *
     * @param searchDTO 搜索参数
     * @return 分页列表
     */
    @PostMapping("/search")
    PageResult<RcvSysUserVO> search(@RequestBody SearchDTO searchDTO);

    /**
     * 新增
     *
     * @param addRcvSysUserDTO 新增参数
     */
    @PostMapping("/add")
    void add(@RequestBody AddRcvSysUserDTO addRcvSysUserDTO);

    /**
     * 批量新增
     *
     * @param addRcvSysUserDTOList 新增参数
     */
    @PostMapping("/addBatch")
    void addBatch(@RequestBody List<AddRcvSysUserDTO> addRcvSysUserDTOList);

    /**
     * 新增或编辑
     *
     * @param editRcvSysUserDTO 新增或编辑参数
     */
    @PostMapping("/addOrEdit")
    void addOrEdit(@RequestBody EditRcvSysUserDTO editRcvSysUserDTO);

    /**
     * 批量新增或编辑
     *
     * @param editRcvSysUserDTOList 新增或编辑参数
     */
    @PostMapping("/addOrEditBatch")
    void addOrEditBatch(@RequestBody List<EditRcvSysUserDTO> editRcvSysUserDTOList);

    /**
     * 编辑
     *
     * @param editRcvSysUserDTO 编辑参数
     */
    @PutMapping("/edit")
    void edit(@RequestBody EditRcvSysUserDTO editRcvSysUserDTO);

    /**
     * 批量编辑
     *
     * @param editRcvSysUserDTO 编辑参数
     */
    @PutMapping("/editBatchById")
    void editBatchById(@RequestBody List<EditRcvSysUserDTO> editRcvSysUserDTO);

    /**
     * 批量删除
     *
     * @param deleteRcvSysUserDTO 删除参数
     */
    @DeleteMapping("/delete")
    void delete(@RequestBody DeleteRcvSysUserDTO deleteRcvSysUserDTO);

    /**
     * 按主键删除
     *
     * @param id 删除参数
     */
    @DeleteMapping("/deleteById/{id}")
    void deleteById(@PathVariable(value = "id") Serializable id);

    /**
     * 按属性删除
     *
     * @param propertyName  删除属性名
     * @param propertyValue 删除属性值
     */
    @DeleteMapping("/deleteByProp")
    void deleteBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Object propertyValue);

    /**
     * 按属性值集合删除
     *
     * @param propertyName  删除属性名
     * @param propertyValue 删除属性值集合
     */
    @DeleteMapping("/deleteByProps")
    void deleteBy(@RequestParam("propertyName") String propertyName, @RequestParam("propertyValue") Collection<Serializable> propertyValue);

    /**
     * 按主键集合批量删除
     *
     * @param ids 删除参数
     */
    @DeleteMapping("/deleteByIds")
    void deleteByIds(@RequestBody Collection<Serializable> ids);

    /**
     * 名称不重复
     *
     * @param id   主键
     * @param name 名称
     * @return 名称重复数量
     */
    @GetMapping("/findByIdAndName")
    int findByIdAndName(@RequestParam("id") Serializable id, @RequestParam("name") String name);
}
